@@ -1013,12 +1013,15 @@ class TestDhcpAgentEventHandler(base.BaseTestCase):
         payload = dict(port=fake_port2)
         self.cache.get_network_by_id.return_value = fake_network
         self.cache.get_port_by_id.return_value = fake_port2
-        self.dhcp.port_update_end(None, payload)
-        self.cache.assert_has_calls(
-            [mock.call.get_network_by_id(fake_port2.network_id),
-             mock.call.put_port(mock.ANY)])
-        self.call_driver.assert_called_once_with('reload_allocations',
-                                                 fake_network)
+        with mock.patch.object(
+                self.dhcp, 'update_isolated_metadata_proxy') as ump:
+            self.dhcp.port_update_end(None, payload)
+            self.cache.assert_has_calls(
+                [mock.call.get_network_by_id(fake_port2.network_id),
+                 mock.call.put_port(mock.ANY)])
+            self.call_driver.assert_called_once_with('reload_allocations',
+                                                     fake_network)
+            self.assertTrue(ump.called)
 
     def test_port_update_end_grabs_lock(self):
         payload = dict(port=fake_port2)
@@ -1034,12 +1037,15 @@ class TestDhcpAgentEventHandler(base.BaseTestCase):
         updated_fake_port1 = copy.deepcopy(fake_port1)
         updated_fake_port1.fixed_ips[0].ip_address = '172.9.9.99'
         self.cache.get_port_by_id.return_value = updated_fake_port1
-        self.dhcp.port_update_end(None, payload)
-        self.cache.assert_has_calls(
-            [mock.call.get_network_by_id(fake_port1.network_id),
-             mock.call.put_port(mock.ANY)])
-        self.call_driver.assert_has_calls(
-            [mock.call.call_driver('reload_allocations', fake_network)])
+        with mock.patch.object(
+                self.dhcp, 'update_isolated_metadata_proxy') as ump:
+            self.dhcp.port_update_end(None, payload)
+            self.cache.assert_has_calls(
+                [mock.call.get_network_by_id(fake_port1.network_id),
+                 mock.call.put_port(mock.ANY)])
+            self.call_driver.assert_has_calls(
+                [mock.call.call_driver('reload_allocations', fake_network)])
+            self.assertTrue(ump.called)
 
     def test_port_update_change_subnet_on_dhcp_agents_port(self):
         self.cache.get_network_by_id.return_value = fake_network
@@ -1092,15 +1098,18 @@ class TestDhcpAgentEventHandler(base.BaseTestCase):
         self.cache.get_network_by_id.return_value = fake_network
         self.cache.get_port_by_id.return_value = fake_port2
 
-        self.dhcp.port_delete_end(None, payload)
-        self.cache.assert_has_calls(
-            [mock.call.get_port_by_id(fake_port2.id),
-             mock.call.deleted_ports.add(fake_port2.id),
-             mock.call.get_port_by_id(fake_port2.id),
-             mock.call.get_network_by_id(fake_network.id),
-             mock.call.remove_port(fake_port2)])
-        self.call_driver.assert_has_calls(
-            [mock.call.call_driver('reload_allocations', fake_network)])
+        with mock.patch.object(
+                self.dhcp, 'update_isolated_metadata_proxy') as ump:
+            self.dhcp.port_delete_end(None, payload)
+            self.cache.assert_has_calls(
+                [mock.call.get_port_by_id(fake_port2.id),
+                 mock.call.deleted_ports.add(fake_port2.id),
+                 mock.call.get_port_by_id(fake_port2.id),
+                 mock.call.get_network_by_id(fake_network.id),
+                 mock.call.remove_port(fake_port2)])
+            self.call_driver.assert_has_calls(
+                [mock.call.call_driver('reload_allocations', fake_network)])
+            self.assertTrue(ump.called)
 
     def test_port_delete_end_unknown_port(self):
         payload = dict(port_id='unknown')
